@@ -21,11 +21,10 @@
 #   along with libtunepimp; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#   $Id: __init__.py,v 1.2 2004/03/25 09:20:15 robert Exp $
+#   $Id: __init__.py.in 7314 2006-04-22 20:15:08Z luks $
 #
 #---------------------------------------------------------------------------
-from _tunepimp import *
 
-__version__ = _tunepimp.__version__
-__doc__ = _tunepimp.__doc__
+__version__ = '0.5.2'
 __all__ = ['tunepimp', 'track', 'metadata']
+
